##################
Spruce-collections
##################

Spruce-collections is a Python library of container data types.  It is
an extension of Python's collections_ module and built-in mapping_,
sequence_, and set_ data types.


.. _collections: http://docs.python.org/2/library/collections

.. _mapping: \
    http://docs.python.org/2/library/stdtypes.html#mapping-types-dict

.. _sequence: \
    http://docs.python.org/2/library/stdtypes.html#sequence-types-str-unicode-list-tuple-bytearray-buffer-xrange

.. _set: \
    http://docs.python.org/2/library/stdtypes.html#set-types-set-frozenset
